@@ -1,9 +1,7 @@
-from .api.main import HydroServer
-from .etl.hydroserver_etl import HydroServerETL
+from .api.client import HydroServer
 from .quality import HydroServerQualityControl
 
 __all__ = [
     "HydroServer",
     "HydroServerQualityControl",
-    "HydroServerETL",
 ]
